@@ -1,6 +1,6 @@
 import functools
 import inspect
-from typing import Callable, List, Any, Dict
+from typing import Any, Callable, Dict, List
 
 
 async def execute_middlewares(func: Callable, routine_func: Callable, middlewares: List, *args: Any) -> Any:
@@ -17,7 +17,10 @@ async def execute_middlewares(func: Callable, routine_func: Callable, middleware
 
             middleware = middlewares[idx]  # type: Callable
 
-            arg_len = len(inspect.getfullargspec(middleware).args) - (len(inspect.getfullargspec(middleware).defaults) if inspect.getfullargspec(middleware).defaults else 0)
+            arg_len = len(inspect.getfullargspec(middleware).args)
+            defaults = inspect.getfullargspec(middleware).defaults
+            if defaults:
+                arg_len = arg_len - len(defaults)
             middleware_arguments = [_func, *args, middleware_context][0:arg_len]
 
             return await middleware(*middleware_arguments, *ma, **mkw)
