@@ -1,16 +1,18 @@
-import logging
-import aioamqp
-import time
-import hashlib
-import re
-import binascii
 import asyncio
-import inspect
+import binascii
 import functools
-from typing import Any, Dict, Union, Optional, Callable, Match, Awaitable, List
-from tomodachi.invoker import Invoker
+import hashlib
+import inspect
+import logging
+import re
+import time
+from typing import Any, Awaitable, Callable, Dict, List, Match, Optional, Union
+
+import aioamqp
+
 from tomodachi.helpers.dict import merge_dicts
 from tomodachi.helpers.middleware import execute_middlewares
+from tomodachi.invoker import Invoker
 
 MESSAGE_PROTOCOL_DEFAULT = '2594418c-5771-454a-a7f9-8f83ae82812a'
 MESSAGE_ROUTING_KEY_PREFIX = '38f58822-25f6-458a-985c-52701d40dbbc'
@@ -268,14 +270,14 @@ class AmqpTransport(Invoker):
             stop_method = getattr(obj, '_stop_service', None)
 
             async def stop_service(*args: Any, **kwargs: Any) -> None:
-                if stop_method:
-                    await stop_method(*args, **kwargs)
                 logging.getLogger('aioamqp.protocol').setLevel(logging.ERROR)
                 await cls.protocol.close()
                 cls.transport.close()
                 cls.channel = None
                 cls.transport = None
                 cls.protocol = None
+                if stop_method:
+                    await stop_method(*args, **kwargs)
 
             setattr(obj, '_stop_service', stop_service)
 
