@@ -1,25 +1,33 @@
-import re
 import asyncio
-import logging
-import time
+import functools
+import inspect
 import ipaddress
+import logging
 import os
 import pathlib
-import inspect
+import re
+import time
 import uuid
-import colorama
-import functools
 from logging.handlers import WatchedFileHandler
-from typing import Any, Dict, List, Tuple, Union, Optional, Callable, SupportsInt, Awaitable, Mapping, Iterable  # noqa
-from multidict import CIMultiDict, CIMultiDictProxy
-from aiohttp import web, web_server, web_protocol, web_urldispatcher, hdrs, WSMsgType
-from aiohttp.web_fileresponse import FileResponse
-from aiohttp.http import HttpVersion
+from typing import Any, Awaitable, Callable, Dict, Iterable, List, Mapping, Optional, SupportsInt, Tuple, Union  # noqa
+
+import colorama
+from aiohttp import WSMsgType, hdrs, web, web_protocol, web_server, web_urldispatcher
 from aiohttp.helpers import BasicAuth
+from aiohttp.http import HttpVersion
 from aiohttp.streams import EofStream
-from tomodachi.invoker import Invoker
+from aiohttp.web_fileresponse import FileResponse
+from multidict import CIMultiDict, CIMultiDictProxy
+
 from tomodachi.helpers.dict import merge_dicts
 from tomodachi.helpers.middleware import execute_middlewares
+from tomodachi.invoker import Invoker
+
+try:
+    CancelledError = asyncio.exceptions.CancelledError  # type: ignore
+except Exception as e:
+    class CancelledError(Exception):  # type: ignore
+        pass
 
 
 class HttpException(Exception):
@@ -110,7 +118,7 @@ class RequestHandler(web_protocol.RequestHandler):  # type: ignore
                     request.headers.get('User-Agent', '').replace('"', '')
                 ))
 
-        headers = {}
+        headers = CIMultiDict({})  # type: CIMultiDict
         headers[hdrs.CONTENT_TYPE] = 'text/plain; charset=utf-8'
 
         msg = '' if status == 500 or not message else message
@@ -244,6 +252,9 @@ class HttpTransport(Invoker):
                 return_value = (await routine) if isinstance(routine, Awaitable) else routine  # type: Union[str, bytes, Dict, List, Tuple, web.Response, Response]
                 return return_value
 
+            if not context.get('_http_accept_new_requests'):
+                raise web.HTTPServiceUnavailable()
+
             if pre_handler_func:
                 await pre_handler_func(obj, request)
 
@@ -596,7 +607,17 @@ class HttpTransport(Invoker):
 
                         return response
 
-                return await asyncio.shield(func())
+                task = asyncio.ensure_future(asyncio.shield(func()))
+                context['_http_active_requests'] = context.get('_http_active_requests', set())
+                context['_http_active_requests'].add(task)
+                try:
+                    result = await task
+                except (Exception, CancelledError):
+                    context['_http_active_requests'].remove(task)
+                    raise
+                context['_http_active_requests'].remove(task)
+
+                return task.result()
 
             app = web.Application(middlewares=[middleware],  # type: ignore
                                   client_max_size=(1024 ** 2) * 100)  # type: web.Application
@@ -615,6 +636,7 @@ class HttpTransport(Invoker):
                     resource.add_route('HEAD', handler, expect_handler=None)  # type: ignore
                 resource.add_route(method.upper(), handler, expect_handler=None)  # type: ignore
 
+            context['_http_accept_new_requests'] = True
             port = context.get('options', {}).get('http', {}).get('port', 9700)
             host = context.get('options', {}).get('http', {}).get('host', '0.0.0.0')
 
@@ -623,29 +645,57 @@ class HttpTransport(Invoker):
                 server_task = loop.create_server(Server(app._handle, request_factory=app._make_request, server_header=server_header or '', access_log=access_log, keepalive_timeout=0, tcp_keepalive=False), host, port)  # type: ignore
                 server = await server_task  # type: ignore
             except OSError as e:
+                context['_http_accept_new_requests'] = False
                 error_message = re.sub('.*: ', '', e.strerror)
                 logging.getLogger('transport.http').warning('Unable to bind service [http] to http://{}:{}/ ({})'.format('127.0.0.1' if host == '0.0.0.0' else host, port, error_message))
                 raise HttpException(str(e), log_level=context.get('log_level')) from e
 
-            port = int(server.sockets[0].getsockname()[1])
+            if server.sockets:
+                socket_address = server.sockets[0].getsockname()
+                if socket_address:
+                    port = int(socket_address[1])
             context['_http_port'] = port
 
             stop_method = getattr(obj, '_stop_service', None)
 
             async def stop_service(*args: Any, **kwargs: Any) -> None:
-                if stop_method:
-                    await stop_method(*args, **kwargs)
-                open_websockets = context.get('_http_open_websockets', [])[:]
-                for websocket in open_websockets:
-                    try:
-                        await websocket.close()
-                    except Exception:
-                        pass
+                context['_http_accept_new_requests'] = False
                 server.close()
+                await server.wait_closed()
+
+                open_websockets = context.get('_http_open_websockets', [])[:]
+                if open_websockets:
+                    logging.getLogger('transport.http').info('Closing websocket connections')
+                    tasks = []
+                    for websocket in open_websockets:
+                        try:
+                            tasks.append(asyncio.ensure_future(websocket.close()))
+                        except Exception:
+                            pass
+                    try:
+                        results = await asyncio.wait_for(asyncio.gather(*tasks, return_exceptions=True), timeout=10)
+                    except (Exception, asyncio.TimeoutError) as e:
+                        pass
+                    context['_http_open_websockets'] = []
+
+                active_requests = context.get('_http_active_requests', set())
+                if active_requests:
+                    termination_grace_period_seconds = context.get('options', {}).get('http', {}).get('termination_grace_period_seconds', 30)
+                    logging.getLogger('transport.http').info('Waiting for active requests to complete - grace period of {} seconds'.format(termination_grace_period_seconds))
+                    try:
+                        results = await asyncio.wait_for(asyncio.gather(*active_requests, return_exceptions=True), timeout=termination_grace_period_seconds)
+                        await asyncio.sleep(1)
+                    except (Exception, asyncio.TimeoutError) as e:
+                        logging.getLogger('transport.http').warning('All active requests did not gracefully finish their execution')
+                        pass
+                    context['_http_active_requests'] = set()
+
                 await app.shutdown()
                 if logger_handler:
                     logging.getLogger('transport.http').removeHandler(logger_handler)
                 await app.cleanup()
+                if stop_method:
+                    await stop_method(*args, **kwargs)
 
             setattr(obj, '_stop_service', stop_service)
 
